@@ -1,5 +1,6 @@
 """Top-level package for anchors."""
-print('hello world')
+from .score import get_guide_residuals, get_gene_residuals
+
 __author__ = """Peter Carl DeWeirdt"""
 __email__ = 'petedeweirdt@gmail.com'
-__version__ = '0.2.0'
+__version__ = '0.3.0'
